@@ -14,7 +14,7 @@ import (
 // AppsService provides access to the installation related functions
 // in the GitHub API.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/
 type AppsService service
 
 // App represents a GitHub App.
@@ -55,54 +55,68 @@ type InstallationTokenOptions struct {
 // InstallationPermissions lists the repository and organization permissions for an installation.
 //
 // Permission names taken from:
-//   https://developer.github.com/v3/apps/permissions/
-//   https://developer.github.com/enterprise/v3/apps/permissions/
+//   https://docs.github.com/en/enterprise-server@3.0/rest/reference/apps#create-an-installation-access-token-for-an-app
+//   https://docs.github.com/en/rest/reference/apps#create-an-installation-access-token-for-an-app
 type InstallationPermissions struct {
-	Administration              *string `json:"administration,omitempty"`
-	Blocking                    *string `json:"blocking,omitempty"`
-	Checks                      *string `json:"checks,omitempty"`
-	Contents                    *string `json:"contents,omitempty"`
-	ContentReferences           *string `json:"content_references,omitempty"`
-	Deployments                 *string `json:"deployments,omitempty"`
-	Emails                      *string `json:"emails,omitempty"`
-	Followers                   *string `json:"followers,omitempty"`
-	Issues                      *string `json:"issues,omitempty"`
-	Metadata                    *string `json:"metadata,omitempty"`
-	Members                     *string `json:"members,omitempty"`
-	OrganizationAdministration  *string `json:"organization_administration,omitempty"`
-	OrganizationHooks           *string `json:"organization_hooks,omitempty"`
-	OrganizationPlan            *string `json:"organization_plan,omitempty"`
-	OrganizationPreReceiveHooks *string `json:"organization_pre_receive_hooks,omitempty"`
-	OrganizationProjects        *string `json:"organization_projects,omitempty"`
-	OrganizationUserBlocking    *string `json:"organization_user_blocking,omitempty"`
-	Packages                    *string `json:"packages,omitempty"`
-	Pages                       *string `json:"pages,omitempty"`
-	PullRequests                *string `json:"pull_requests,omitempty"`
-	RepositoryHooks             *string `json:"repository_hooks,omitempty"`
-	RepositoryProjects          *string `json:"repository_projects,omitempty"`
-	RepositoryPreReceiveHooks   *string `json:"repository_pre_receive_hooks,omitempty"`
-	SingleFile                  *string `json:"single_file,omitempty"`
-	Statuses                    *string `json:"statuses,omitempty"`
-	TeamDiscussions             *string `json:"team_discussions,omitempty"`
-	VulnerabilityAlerts         *string `json:"vulnerability_alerts,omitempty"`
+	Actions                       *string `json:"actions,omitempty"`
+	Administration                *string `json:"administration,omitempty"`
+	Blocking                      *string `json:"blocking,omitempty"`
+	Checks                        *string `json:"checks,omitempty"`
+	Contents                      *string `json:"contents,omitempty"`
+	ContentReferences             *string `json:"content_references,omitempty"`
+	Deployments                   *string `json:"deployments,omitempty"`
+	Emails                        *string `json:"emails,omitempty"`
+	Environments                  *string `json:"environments,omitempty"`
+	Followers                     *string `json:"followers,omitempty"`
+	Issues                        *string `json:"issues,omitempty"`
+	Metadata                      *string `json:"metadata,omitempty"`
+	Members                       *string `json:"members,omitempty"`
+	OrganizationAdministration    *string `json:"organization_administration,omitempty"`
+	OrganizationHooks             *string `json:"organization_hooks,omitempty"`
+	OrganizationPlan              *string `json:"organization_plan,omitempty"`
+	OrganizationPreReceiveHooks   *string `json:"organization_pre_receive_hooks,omitempty"`
+	OrganizationProjects          *string `json:"organization_projects,omitempty"`
+	OrganizationSecrets           *string `json:"organization_secrets,omitempty"`
+	OrganizationSelfHostedRunners *string `json:"organization_self_hosted_runners,omitempty"`
+	OrganizationUserBlocking      *string `json:"organization_user_blocking,omitempty"`
+	Packages                      *string `json:"packages,omitempty"`
+	Pages                         *string `json:"pages,omitempty"`
+	PullRequests                  *string `json:"pull_requests,omitempty"`
+	RepositoryHooks               *string `json:"repository_hooks,omitempty"`
+	RepositoryProjects            *string `json:"repository_projects,omitempty"`
+	RepositoryPreReceiveHooks     *string `json:"repository_pre_receive_hooks,omitempty"`
+	Secrets                       *string `json:"secrets,omitempty"`
+	SecretScanningAlerts          *string `json:"secret_scanning_alerts,omitempty"`
+	SecurityEvents                *string `json:"security_events,omitempty"`
+	SingleFile                    *string `json:"single_file,omitempty"`
+	Statuses                      *string `json:"statuses,omitempty"`
+	TeamDiscussions               *string `json:"team_discussions,omitempty"`
+	VulnerabilityAlerts           *string `json:"vulnerability_alerts,omitempty"`
+	Workflows                     *string `json:"workflows,omitempty"`
 }
 
 // Installation represents a GitHub Apps installation.
 type Installation struct {
-	ID                  *int64                   `json:"id,omitempty"`
-	AppID               *int64                   `json:"app_id,omitempty"`
-	TargetID            *int64                   `json:"target_id,omitempty"`
-	Account             *User                    `json:"account,omitempty"`
-	AccessTokensURL     *string                  `json:"access_tokens_url,omitempty"`
-	RepositoriesURL     *string                  `json:"repositories_url,omitempty"`
-	HTMLURL             *string                  `json:"html_url,omitempty"`
-	TargetType          *string                  `json:"target_type,omitempty"`
-	SingleFileName      *string                  `json:"single_file_name,omitempty"`
-	RepositorySelection *string                  `json:"repository_selection,omitempty"`
-	Events              []string                 `json:"events,omitempty"`
-	Permissions         *InstallationPermissions `json:"permissions,omitempty"`
-	CreatedAt           *Timestamp               `json:"created_at,omitempty"`
-	UpdatedAt           *Timestamp               `json:"updated_at,omitempty"`
+	ID                     *int64                   `json:"id,omitempty"`
+	NodeID                 *string                  `json:"node_id,omitempty"`
+	AppID                  *int64                   `json:"app_id,omitempty"`
+	AppSlug                *string                  `json:"app_slug,omitempty"`
+	TargetID               *int64                   `json:"target_id,omitempty"`
+	Account                *User                    `json:"account,omitempty"`
+	AccessTokensURL        *string                  `json:"access_tokens_url,omitempty"`
+	RepositoriesURL        *string                  `json:"repositories_url,omitempty"`
+	HTMLURL                *string                  `json:"html_url,omitempty"`
+	TargetType             *string                  `json:"target_type,omitempty"`
+	SingleFileName         *string                  `json:"single_file_name,omitempty"`
+	RepositorySelection    *string                  `json:"repository_selection,omitempty"`
+	Events                 []string                 `json:"events,omitempty"`
+	SingleFilePaths        []string                 `json:"single_file_paths,omitempty"`
+	Permissions            *InstallationPermissions `json:"permissions,omitempty"`
+	CreatedAt              *Timestamp               `json:"created_at,omitempty"`
+	UpdatedAt              *Timestamp               `json:"updated_at,omitempty"`
+	HasMultipleSingleFiles *bool                    `json:"has_multiple_single_files,omitempty"`
+	SuspendedBy            *User                    `json:"suspended_by,omitempty"`
+	SuspendedAt            *Timestamp               `json:"suspended_at,omitempty"`
 }
 
 // Attachment represents a GitHub Apps attachment.
@@ -112,6 +126,13 @@ type Attachment struct {
 	Body  *string `json:"body,omitempty"`
 }
 
+// ContentReference represents a reference to a URL in an issue or pull request.
+type ContentReference struct {
+	ID        *int64  `json:"id,omitempty"`
+	NodeID    *string `json:"node_id,omitempty"`
+	Reference *string `json:"reference,omitempty"`
+}
+
 func (i Installation) String() string {
 	return Stringify(i)
 }
@@ -123,8 +144,8 @@ func (i Installation) String() string {
 // You can find this on the settings page for your GitHub App
 // (e.g., https://github.com/settings/apps/:app_slug).
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#get-the-authenticated-app
-// GitHub API docs: https://developer.github.com/v3/apps/#get-an-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#get-the-authenticated-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#get-an-app
 func (s *AppsService) Get(ctx context.Context, appSlug string) (*App, *Response, error) {
 	var u string
 	if appSlug != "" {
@@ -138,9 +159,6 @@ func (s *AppsService) Get(ctx context.Context, appSlug string) (*App, *Response,
 		return nil, nil, err
 	}
 
-	// TODO: remove custom Accept header when this API fully launches.
-	req.Header.Set("Accept", mediaTypeIntegrationPreview)
-
 	app := new(App)
 	resp, err := s.client.Do(ctx, req, app)
 	if err != nil {
@@ -152,7 +170,7 @@ func (s *AppsService) Get(ctx context.Context, appSlug string) (*App, *Response,
 
 // ListInstallations lists the installations that the current GitHub App has.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#list-installations-for-the-authenticated-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#list-installations-for-the-authenticated-app
 func (s *AppsService) ListInstallations(ctx context.Context, opts *ListOptions) ([]*Installation, *Response, error) {
 	u, err := addOptions("app/installations", opts)
 	if err != nil {
@@ -164,9 +182,6 @@ func (s *AppsService) ListInstallations(ctx context.Context, opts *ListOptions)
 		return nil, nil, err
 	}
 
-	// TODO: remove custom Accept header when this API fully launches.
-	req.Header.Set("Accept", mediaTypeIntegrationPreview)
-
 	var i []*Installation
 	resp, err := s.client.Do(ctx, req, &i)
 	if err != nil {
@@ -178,14 +193,14 @@ func (s *AppsService) ListInstallations(ctx context.Context, opts *ListOptions)
 
 // GetInstallation returns the specified installation.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#get-an-installation-for-the-authenticated-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#get-an-installation-for-the-authenticated-app
 func (s *AppsService) GetInstallation(ctx context.Context, id int64) (*Installation, *Response, error) {
 	return s.getInstallation(ctx, fmt.Sprintf("app/installations/%v", id))
 }
 
 // ListUserInstallations lists installations that are accessible to the authenticated user.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/installations/#list-app-installations-accessible-to-the-user-access-token
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#list-app-installations-accessible-to-the-user-access-token
 func (s *AppsService) ListUserInstallations(ctx context.Context, opts *ListOptions) ([]*Installation, *Response, error) {
 	u, err := addOptions("user/installations", opts)
 	if err != nil {
@@ -197,9 +212,6 @@ func (s *AppsService) ListUserInstallations(ctx context.Context, opts *ListOptio
 		return nil, nil, err
 	}
 
-	// TODO: remove custom Accept header when this API fully launches.
-	req.Header.Set("Accept", mediaTypeIntegrationPreview)
-
 	var i struct {
 		Installations []*Installation `json:"installations"`
 	}
@@ -213,7 +225,7 @@ func (s *AppsService) ListUserInstallations(ctx context.Context, opts *ListOptio
 
 // SuspendInstallation suspends the specified installation.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#suspend-an-app-installation
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#suspend-an-app-installation
 func (s *AppsService) SuspendInstallation(ctx context.Context, id int64) (*Response, error) {
 	u := fmt.Sprintf("app/installations/%v/suspended", id)
 
@@ -227,7 +239,7 @@ func (s *AppsService) SuspendInstallation(ctx context.Context, id int64) (*Respo
 
 // UnsuspendInstallation unsuspends the specified installation.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#unsuspend-an-app-installation
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#unsuspend-an-app-installation
 func (s *AppsService) UnsuspendInstallation(ctx context.Context, id int64) (*Response, error) {
 	u := fmt.Sprintf("app/installations/%v/suspended", id)
 
@@ -241,7 +253,7 @@ func (s *AppsService) UnsuspendInstallation(ctx context.Context, id int64) (*Res
 
 // DeleteInstallation deletes the specified installation.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#delete-an-installation-for-the-authenticated-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#delete-an-installation-for-the-authenticated-app
 func (s *AppsService) DeleteInstallation(ctx context.Context, id int64) (*Response, error) {
 	u := fmt.Sprintf("app/installations/%v", id)
 
@@ -250,15 +262,12 @@ func (s *AppsService) DeleteInstallation(ctx context.Context, id int64) (*Respon
 		return nil, err
 	}
 
-	// TODO: remove custom Accept header when this API fully launches.
-	req.Header.Set("Accept", mediaTypeIntegrationPreview)
-
 	return s.client.Do(ctx, req, nil)
 }
 
 // CreateInstallationToken creates a new installation token.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#create-an-installation-access-token-for-an-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#create-an-installation-access-token-for-an-app
 func (s *AppsService) CreateInstallationToken(ctx context.Context, id int64, opts *InstallationTokenOptions) (*InstallationToken, *Response, error) {
 	u := fmt.Sprintf("app/installations/%v/access_tokens", id)
 
@@ -267,9 +276,6 @@ func (s *AppsService) CreateInstallationToken(ctx context.Context, id int64, opt
 		return nil, nil, err
 	}
 
-	// TODO: remove custom Accept header when this API fully launches.
-	req.Header.Set("Accept", mediaTypeIntegrationPreview)
-
 	t := new(InstallationToken)
 	resp, err := s.client.Do(ctx, req, t)
 	if err != nil {
@@ -281,7 +287,7 @@ func (s *AppsService) CreateInstallationToken(ctx context.Context, id int64, opt
 
 // CreateAttachment creates a new attachment on user comment containing a url.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/installations/#create-a-content-attachment
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#create-a-content-attachment
 func (s *AppsService) CreateAttachment(ctx context.Context, contentReferenceID int64, title, body string) (*Attachment, *Response, error) {
 	u := fmt.Sprintf("content_references/%v/attachments", contentReferenceID)
 	payload := &Attachment{Title: String(title), Body: String(body)}
@@ -291,7 +297,7 @@ func (s *AppsService) CreateAttachment(ctx context.Context, contentReferenceID i
 	}
 
 	// TODO: remove custom Accept headers when APIs fully launch.
-	req.Header.Set("Accept", mediaTypeReactionsPreview)
+	req.Header.Set("Accept", mediaTypeContentAttachmentsPreview)
 
 	m := &Attachment{}
 	resp, err := s.client.Do(ctx, req, m)
@@ -304,14 +310,14 @@ func (s *AppsService) CreateAttachment(ctx context.Context, contentReferenceID i
 
 // FindOrganizationInstallation finds the organization's installation information.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#get-an-organization-installation-for-the-authenticated-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#get-an-organization-installation-for-the-authenticated-app
 func (s *AppsService) FindOrganizationInstallation(ctx context.Context, org string) (*Installation, *Response, error) {
 	return s.getInstallation(ctx, fmt.Sprintf("orgs/%v/installation", org))
 }
 
 // FindRepositoryInstallation finds the repository's installation information.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#get-a-repository-installation-for-the-authenticated-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#get-a-repository-installation-for-the-authenticated-app
 func (s *AppsService) FindRepositoryInstallation(ctx context.Context, owner, repo string) (*Installation, *Response, error) {
 	return s.getInstallation(ctx, fmt.Sprintf("repos/%v/%v/installation", owner, repo))
 }
@@ -325,7 +331,7 @@ func (s *AppsService) FindRepositoryInstallationByID(ctx context.Context, id int
 
 // FindUserInstallation finds the user's installation information.
 //
-// GitHub API docs: https://developer.github.com/v3/apps/#get-a-user-installation-for-the-authenticated-app
+// GitHub API docs: https://docs.github.com/en/free-pro-team@latest/rest/reference/apps/#get-a-user-installation-for-the-authenticated-app
 func (s *AppsService) FindUserInstallation(ctx context.Context, user string) (*Installation, *Response, error) {
 	return s.getInstallation(ctx, fmt.Sprintf("users/%v/installation", user))
 }
@@ -336,9 +342,6 @@ func (s *AppsService) getInstallation(ctx context.Context, url string) (*Install
 		return nil, nil, err
 	}
 
-	// TODO: remove custom Accept header when this API fully launches.
-	req.Header.Set("Accept", mediaTypeIntegrationPreview)
-
 	i := new(Installation)
 	resp, err := s.client.Do(ctx, req, i)
 	if err != nil {
