@@ -12,7 +12,7 @@ import (
 	"fmt"
 	"log"
 
-	"github.com/google/go-github/v32/github"
+	"github.com/google/go-github/v38/github"
 )
 
 func ExampleClient_Markdown() {
@@ -21,7 +21,8 @@ func ExampleClient_Markdown() {
 	input := "# heading #\n\nLink to issue #1"
 	opt := &github.MarkdownOptions{Mode: "gfm", Context: "google/go-github"}
 
-	output, _, err := client.Markdown(context.Background(), input, opt)
+	ctx := context.Background()
+	output, _, err := client.Markdown(ctx, input, opt)
 	if err != nil {
 		fmt.Println(err)
 	}
@@ -32,7 +33,8 @@ func ExampleClient_Markdown() {
 func ExampleRepositoriesService_GetReadme() {
 	client := github.NewClient(nil)
 
-	readme, _, err := client.Repositories.GetReadme(context.Background(), "google", "go-github", nil)
+	ctx := context.Background()
+	readme, _, err := client.Repositories.GetReadme(ctx, "google", "go-github", nil)
 	if err != nil {
 		fmt.Println(err)
 		return
@@ -53,7 +55,8 @@ func ExampleRepositoriesService_List() {
 	user := "willnorris"
 	opt := &github.RepositoryListOptions{Type: "owner", Sort: "updated", Direction: "desc"}
 
-	repos, _, err := client.Repositories.List(context.Background(), user, opt)
+	ctx := context.Background()
+	repos, _, err := client.Repositories.List(ctx, user, opt)
 	if err != nil {
 		fmt.Println(err)
 	}
@@ -94,7 +97,8 @@ func ExampleUsersService_ListAll() {
 	client := github.NewClient(nil)
 	opts := &github.UserListOptions{}
 	for {
-		users, _, err := client.Users.ListAll(context.Background(), opts)
+		ctx := context.Background()
+		users, _, err := client.Users.ListAll(ctx, opts)
 		if err != nil {
 			log.Fatalf("error listing users: %v", err)
 		}
@@ -124,7 +128,8 @@ func ExamplePullRequestsService_Create() {
 		MaintainerCanModify: github.Bool(true),
 	}
 
-	pr, _, err := client.PullRequests.Create(context.Background(), "myOrganization", "myRepository", newPR)
+	ctx := context.Background()
+	pr, _, err := client.PullRequests.Create(ctx, "myOrganization", "myRepository", newPR)
 	if err != nil {
 		fmt.Println(err)
 		return
