@@ -10,11 +10,12 @@ import (
 	"encoding/json"
 	"fmt"
 	"net/http"
-	"reflect"
 	"testing"
+
+	"github.com/google/go-cmp/cmp"
 )
 
-func TestOrganization_marshal(t *testing.T) {
+func TestOrganization_Marshal(t *testing.T) {
 	testJSONMarshal(t, &Organization{}, "{}")
 
 	o := &Organization{
@@ -35,6 +36,9 @@ func TestOrganization_marshal(t *testing.T) {
 		MembersCanCreatePrivateRepos:         Bool(true),
 		MembersCanCreatePublicRepos:          Bool(false),
 		MembersAllowedRepositoryCreationType: String("all"),
+		MembersCanCreatePages:                Bool(true),
+		MembersCanCreatePublicPages:          Bool(false),
+		MembersCanCreatePrivatePages:         Bool(true),
 	}
 	want := `
 		{
@@ -54,7 +58,10 @@ func TestOrganization_marshal(t *testing.T) {
 			"members_can_create_public_repositories": false,
 			"members_can_create_private_repositories": true,
 			"members_can_create_internal_repositories": true,
-			"members_allowed_repository_creation_type": "all"
+			"members_allowed_repository_creation_type": "all",
+			"members_can_create_pages": true,
+			"members_can_create_public_pages": false,
+			"members_can_create_private_pages": true
 		}
 	`
 	testJSONMarshal(t, o, want)
@@ -72,15 +79,25 @@ func TestOrganizationsService_ListAll(t *testing.T) {
 	})
 
 	opt := &OrganizationsListOptions{Since: since}
-	orgs, _, err := client.Organizations.ListAll(context.Background(), opt)
+	ctx := context.Background()
+	orgs, _, err := client.Organizations.ListAll(ctx, opt)
 	if err != nil {
 		t.Errorf("Organizations.ListAll returned error: %v", err)
 	}
 
 	want := []*Organization{{ID: Int64(4314092)}}
-	if !reflect.DeepEqual(orgs, want) {
+	if !cmp.Equal(orgs, want) {
 		t.Errorf("Organizations.ListAll returned %+v, want %+v", orgs, want)
 	}
+
+	const methodName = "ListAll"
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.ListAll(ctx, opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestOrganizationsService_List_authenticatedUser(t *testing.T) {
@@ -92,15 +109,30 @@ func TestOrganizationsService_List_authenticatedUser(t *testing.T) {
 		fmt.Fprint(w, `[{"id":1},{"id":2}]`)
 	})
 
-	orgs, _, err := client.Organizations.List(context.Background(), "", nil)
+	ctx := context.Background()
+	orgs, _, err := client.Organizations.List(ctx, "", nil)
 	if err != nil {
 		t.Errorf("Organizations.List returned error: %v", err)
 	}
 
 	want := []*Organization{{ID: Int64(1)}, {ID: Int64(2)}}
-	if !reflect.DeepEqual(orgs, want) {
+	if !cmp.Equal(orgs, want) {
 		t.Errorf("Organizations.List returned %+v, want %+v", orgs, want)
 	}
+
+	const methodName = "List"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Organizations.List(ctx, "\n", nil)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.List(ctx, "", nil)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestOrganizationsService_List_specifiedUser(t *testing.T) {
@@ -114,22 +146,38 @@ func TestOrganizationsService_List_specifiedUser(t *testing.T) {
 	})
 
 	opt := &ListOptions{Page: 2}
-	orgs, _, err := client.Organizations.List(context.Background(), "u", opt)
+	ctx := context.Background()
+	orgs, _, err := client.Organizations.List(ctx, "u", opt)
 	if err != nil {
 		t.Errorf("Organizations.List returned error: %v", err)
 	}
 
 	want := []*Organization{{ID: Int64(1)}, {ID: Int64(2)}}
-	if !reflect.DeepEqual(orgs, want) {
+	if !cmp.Equal(orgs, want) {
 		t.Errorf("Organizations.List returned %+v, want %+v", orgs, want)
 	}
+
+	const methodName = "List"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Organizations.List(ctx, "\n", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.List(ctx, "u", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestOrganizationsService_List_invalidUser(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Organizations.List(context.Background(), "%", nil)
+	ctx := context.Background()
+	_, _, err := client.Organizations.List(ctx, "%", nil)
 	testURLParseError(t, err)
 }
 
@@ -143,22 +191,38 @@ func TestOrganizationsService_Get(t *testing.T) {
 		fmt.Fprint(w, `{"id":1, "login":"l", "url":"u", "avatar_url": "a", "location":"l"}`)
 	})
 
-	org, _, err := client.Organizations.Get(context.Background(), "o")
+	ctx := context.Background()
+	org, _, err := client.Organizations.Get(ctx, "o")
 	if err != nil {
 		t.Errorf("Organizations.Get returned error: %v", err)
 	}
 
 	want := &Organization{ID: Int64(1), Login: String("l"), URL: String("u"), AvatarURL: String("a"), Location: String("l")}
-	if !reflect.DeepEqual(org, want) {
+	if !cmp.Equal(org, want) {
 		t.Errorf("Organizations.Get returned %+v, want %+v", org, want)
 	}
+
+	const methodName = "Get"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Organizations.Get(ctx, "\n")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.Get(ctx, "o")
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestOrganizationsService_Get_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Organizations.Get(context.Background(), "%")
+	ctx := context.Background()
+	_, _, err := client.Organizations.Get(ctx, "%")
 	testURLParseError(t, err)
 }
 
@@ -171,15 +235,30 @@ func TestOrganizationsService_GetByID(t *testing.T) {
 		fmt.Fprint(w, `{"id":1, "login":"l", "url":"u", "avatar_url": "a", "location":"l"}`)
 	})
 
-	org, _, err := client.Organizations.GetByID(context.Background(), 1)
+	ctx := context.Background()
+	org, _, err := client.Organizations.GetByID(ctx, 1)
 	if err != nil {
 		t.Fatalf("Organizations.GetByID returned error: %v", err)
 	}
 
 	want := &Organization{ID: Int64(1), Login: String("l"), URL: String("u"), AvatarURL: String("a"), Location: String("l")}
-	if !reflect.DeepEqual(org, want) {
+	if !cmp.Equal(org, want) {
 		t.Errorf("Organizations.GetByID returned %+v, want %+v", org, want)
 	}
+
+	const methodName = "GetByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Organizations.GetByID(ctx, -1)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.GetByID(ctx, 1)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestOrganizationsService_Edit(t *testing.T) {
@@ -194,29 +273,45 @@ func TestOrganizationsService_Edit(t *testing.T) {
 
 		testHeader(t, r, "Accept", mediaTypeMemberAllowedRepoCreationTypePreview)
 		testMethod(t, r, "PATCH")
-		if !reflect.DeepEqual(v, input) {
+		if !cmp.Equal(v, input) {
 			t.Errorf("Request body = %+v, want %+v", v, input)
 		}
 
 		fmt.Fprint(w, `{"id":1}`)
 	})
 
-	org, _, err := client.Organizations.Edit(context.Background(), "o", input)
+	ctx := context.Background()
+	org, _, err := client.Organizations.Edit(ctx, "o", input)
 	if err != nil {
 		t.Errorf("Organizations.Edit returned error: %v", err)
 	}
 
 	want := &Organization{ID: Int64(1)}
-	if !reflect.DeepEqual(org, want) {
+	if !cmp.Equal(org, want) {
 		t.Errorf("Organizations.Edit returned %+v, want %+v", org, want)
 	}
+
+	const methodName = "Edit"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Organizations.Edit(ctx, "\n", input)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.Edit(ctx, "o", input)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestOrganizationsService_Edit_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Organizations.Edit(context.Background(), "%", nil)
+	ctx := context.Background()
+	_, _, err := client.Organizations.Edit(ctx, "%", nil)
 	testURLParseError(t, err)
 }
 
@@ -226,26 +321,41 @@ func TestOrganizationsService_ListInstallations(t *testing.T) {
 
 	mux.HandleFunc("/orgs/o/installations", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-		testHeader(t, r, "Accept", mediaTypeIntegrationPreview)
 		fmt.Fprint(w, `{"total_count": 1, "installations": [{ "id": 1, "app_id": 5}]}`)
 	})
 
-	apps, _, err := client.Organizations.ListInstallations(context.Background(), "o", nil)
+	ctx := context.Background()
+	apps, _, err := client.Organizations.ListInstallations(ctx, "o", nil)
 	if err != nil {
 		t.Errorf("Organizations.ListInstallations returned error: %v", err)
 	}
 
 	want := &OrganizationInstallations{TotalCount: Int(1), Installations: []*Installation{{ID: Int64(1), AppID: Int64(5)}}}
-	if !reflect.DeepEqual(apps, want) {
+	if !cmp.Equal(apps, want) {
 		t.Errorf("Organizations.ListInstallations returned %+v, want %+v", apps, want)
 	}
+
+	const methodName = "ListInstallations"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Organizations.ListInstallations(ctx, "\no", nil)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.ListInstallations(ctx, "o", nil)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestOrganizationsService_ListInstallations_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Organizations.ListInstallations(context.Background(), "%", nil)
+	ctx := context.Background()
+	_, _, err := client.Organizations.ListInstallations(ctx, "%", nil)
 	testURLParseError(t, err)
 
 }
@@ -256,24 +366,80 @@ func TestOrganizationsService_ListInstallations_withListOptions(t *testing.T) {
 
 	mux.HandleFunc("/orgs/o/installations", func(w http.ResponseWriter, r *http.Request) {
 		testMethod(t, r, "GET")
-		testHeader(t, r, "Accept", mediaTypeIntegrationPreview)
 		testFormValues(t, r, values{"page": "2"})
 		fmt.Fprint(w, `{"total_count": 2, "installations": [{ "id": 2, "app_id": 10}]}`)
 	})
 
-	apps, _, err := client.Organizations.ListInstallations(context.Background(), "o", &ListOptions{Page: 2})
+	ctx := context.Background()
+	apps, _, err := client.Organizations.ListInstallations(ctx, "o", &ListOptions{Page: 2})
 	if err != nil {
 		t.Errorf("Organizations.ListInstallations returned error: %v", err)
 	}
 
 	want := &OrganizationInstallations{TotalCount: Int(2), Installations: []*Installation{{ID: Int64(2), AppID: Int64(10)}}}
-	if !reflect.DeepEqual(apps, want) {
+	if !cmp.Equal(apps, want) {
 		t.Errorf("Organizations.ListInstallations returned %+v, want %+v", apps, want)
 	}
 
 	// Test ListOptions failure
-	_, _, err = client.Organizations.ListInstallations(context.Background(), "%", &ListOptions{})
+	_, _, err = client.Organizations.ListInstallations(ctx, "%", &ListOptions{})
 	if err == nil {
 		t.Error("Organizations.ListInstallations returned error: nil")
 	}
+
+	const methodName = "ListInstallations"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Organizations.ListInstallations(ctx, "\n", &ListOptions{Page: 2})
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Organizations.ListInstallations(ctx, "o", &ListOptions{Page: 2})
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
+}
+
+func TestOrganizationInstallations_Marshal(t *testing.T) {
+	testJSONMarshal(t, &OrganizationInstallations{}, "{}")
+
+	o := &OrganizationInstallations{
+		TotalCount:    Int(1),
+		Installations: []*Installation{{ID: Int64(1)}},
+	}
+	want := `{
+		"total_count": 1,
+		"installations": [
+			{
+				"id": 1
+			}
+		]
+	}`
+
+	testJSONMarshal(t, o, want)
+}
+
+func TestPlan_Marshal(t *testing.T) {
+	testJSONMarshal(t, &Plan{}, "{}")
+
+	o := &Plan{
+		Name:          String("name"),
+		Space:         Int(1),
+		Collaborators: Int(1),
+		PrivateRepos:  Int(1),
+		FilledSeats:   Int(1),
+		Seats:         Int(1),
+	}
+	want := `{
+		"name": "name",
+		"space": 1,
+		"collaborators": 1,
+		"private_repos": 1,
+		"filled_seats": 1,
+		"seats": 1
+	}`
+
+	testJSONMarshal(t, o, want)
 }
