@@ -10,9 +10,10 @@ import (
 	"encoding/json"
 	"fmt"
 	"net/http"
-	"reflect"
 	"testing"
 	"time"
+
+	"github.com/google/go-cmp/cmp"
 )
 
 // "Team Discussion Comments" endpoint, when using a teamID.
@@ -117,28 +118,61 @@ func TestTeamsService_ListComments(t *testing.T) {
 	e := tdcEndpointByID("1", "2", "3", "")
 	mux.HandleFunc(e, handleFunc)
 
-	commentsByID, _, err := client.Teams.ListCommentsByID(context.Background(), 1, 2, 3,
+	ctx := context.Background()
+	commentsByID, _, err := client.Teams.ListCommentsByID(ctx, 1, 2, 3,
 		&DiscussionCommentListOptions{Direction: "desc"})
 	if err != nil {
 		t.Errorf("Teams.ListCommentsByID returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentsByID, want) {
+	if !cmp.Equal(commentsByID, want) {
 		t.Errorf("Teams.ListCommentsByID returned %+v, want %+v", commentsByID, want)
 	}
 
 	e = tdcEndpointBySlug("a", "b", "3", "")
 	mux.HandleFunc(e, handleFunc)
 
-	commentsBySlug, _, err := client.Teams.ListCommentsBySlug(context.Background(), "a", "b", 3,
+	commentsBySlug, _, err := client.Teams.ListCommentsBySlug(ctx, "a", "b", 3,
 		&DiscussionCommentListOptions{Direction: "desc"})
 	if err != nil {
 		t.Errorf("Teams.ListCommentsBySlug returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentsBySlug, want) {
+	if !cmp.Equal(commentsBySlug, want) {
 		t.Errorf("Teams.ListCommentsBySlug returned %+v, want %+v", commentsBySlug, want)
 	}
+
+	methodName := "ListCommentsByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListCommentsByID(ctx, -1, -2, -3,
+			&DiscussionCommentListOptions{Direction: "desc"})
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListCommentsByID(ctx, 1, 2, 3,
+			&DiscussionCommentListOptions{Direction: "desc"})
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
+
+	methodName = "ListCommentsBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListCommentsBySlug(ctx, "a\na", "b\nb", -3,
+			&DiscussionCommentListOptions{Direction: "desc"})
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListCommentsBySlug(ctx, "a", "b", 3,
+			&DiscussionCommentListOptions{Direction: "desc"})
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService_GetComment(t *testing.T) {
@@ -154,27 +188,55 @@ func TestTeamsService_GetComment(t *testing.T) {
 	e := tdcEndpointByID("1", "2", "3", "4")
 	mux.HandleFunc(e, handlerFunc)
 
-	commentByID, _, err := client.Teams.GetCommentByID(context.Background(), 1, 2, 3, 4)
+	ctx := context.Background()
+	commentByID, _, err := client.Teams.GetCommentByID(ctx, 1, 2, 3, 4)
 	if err != nil {
 		t.Errorf("Teams.GetCommentByID returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentByID, want) {
+	if !cmp.Equal(commentByID, want) {
 		t.Errorf("Teams.GetCommentByID returned %+v, want %+v", commentByID, want)
 	}
 
 	e = tdcEndpointBySlug("a", "b", "3", "4")
 	mux.HandleFunc(e, handlerFunc)
 
-	commentBySlug, _, err := client.Teams.GetCommentBySlug(context.Background(), "a", "b", 3, 4)
+	commentBySlug, _, err := client.Teams.GetCommentBySlug(ctx, "a", "b", 3, 4)
 	if err != nil {
 		t.Errorf("Teams.GetCommentBySlug returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentBySlug, want) {
+	if !cmp.Equal(commentBySlug, want) {
 		t.Errorf("Teams.GetCommentBySlug returned %+v, want %+v", commentBySlug, want)
 	}
 
+	methodName := "GetCommentByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.GetCommentByID(ctx, -1, -2, -3, -4)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.GetCommentByID(ctx, 1, 2, 3, 4)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
+
+	methodName = "ListCommentsBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.GetCommentBySlug(ctx, "a\na", "b\nb", -3, -4)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.GetCommentBySlug(ctx, "a", "b", 3, 4)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService_CreateComment(t *testing.T) {
@@ -188,7 +250,7 @@ func TestTeamsService_CreateComment(t *testing.T) {
 		json.NewDecoder(r.Body).Decode(v)
 
 		testMethod(t, r, "POST")
-		if !reflect.DeepEqual(v, &input) {
+		if !cmp.Equal(v, &input) {
 			t.Errorf("Request body = %+v, want %+v", v, input)
 		}
 
@@ -199,26 +261,55 @@ func TestTeamsService_CreateComment(t *testing.T) {
 	e := tdcEndpointByID("1", "2", "3", "")
 	mux.HandleFunc(e, handlerFunc)
 
-	commentByID, _, err := client.Teams.CreateCommentByID(context.Background(), 1, 2, 3, input)
+	ctx := context.Background()
+	commentByID, _, err := client.Teams.CreateCommentByID(ctx, 1, 2, 3, input)
 	if err != nil {
 		t.Errorf("Teams.CreateCommentByID returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentByID, want) {
+	if !cmp.Equal(commentByID, want) {
 		t.Errorf("Teams.CreateCommentByID returned %+v, want %+v", commentByID, want)
 	}
 
 	e = tdcEndpointBySlug("a", "b", "3", "")
 	mux.HandleFunc(e, handlerFunc)
 
-	commentBySlug, _, err := client.Teams.CreateCommentBySlug(context.Background(), "a", "b", 3, input)
+	commentBySlug, _, err := client.Teams.CreateCommentBySlug(ctx, "a", "b", 3, input)
 	if err != nil {
 		t.Errorf("Teams.CreateCommentBySlug returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentBySlug, want) {
+	if !cmp.Equal(commentBySlug, want) {
 		t.Errorf("Teams.CreateCommentBySlug returned %+v, want %+v", commentBySlug, want)
 	}
+
+	methodName := "CreateCommentByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.CreateCommentByID(ctx, -1, -2, -3, input)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.CreateCommentByID(ctx, 1, 2, 3, input)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
+
+	methodName = "CreateCommentBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.CreateCommentBySlug(ctx, "a\na", "b\nb", -3, input)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.CreateCommentBySlug(ctx, "a", "b", 3, input)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService_EditComment(t *testing.T) {
@@ -231,7 +322,7 @@ func TestTeamsService_EditComment(t *testing.T) {
 		json.NewDecoder(r.Body).Decode(v)
 
 		testMethod(t, r, "PATCH")
-		if !reflect.DeepEqual(v, &input) {
+		if !cmp.Equal(v, &input) {
 			t.Errorf("Request body = %+v, want %+v", v, input)
 		}
 
@@ -242,26 +333,55 @@ func TestTeamsService_EditComment(t *testing.T) {
 	e := tdcEndpointByID("1", "2", "3", "4")
 	mux.HandleFunc(e, handlerFunc)
 
-	commentByID, _, err := client.Teams.EditCommentByID(context.Background(), 1, 2, 3, 4, input)
+	ctx := context.Background()
+	commentByID, _, err := client.Teams.EditCommentByID(ctx, 1, 2, 3, 4, input)
 	if err != nil {
 		t.Errorf("Teams.EditCommentByID returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentByID, want) {
+	if !cmp.Equal(commentByID, want) {
 		t.Errorf("Teams.EditCommentByID returned %+v, want %+v", commentByID, want)
 	}
 
 	e = tdcEndpointBySlug("a", "b", "3", "4")
 	mux.HandleFunc(e, handlerFunc)
 
-	commentBySlug, _, err := client.Teams.EditCommentBySlug(context.Background(), "a", "b", 3, 4, input)
+	commentBySlug, _, err := client.Teams.EditCommentBySlug(ctx, "a", "b", 3, 4, input)
 	if err != nil {
 		t.Errorf("Teams.EditCommentBySlug returned error: %v", err)
 	}
 
-	if !reflect.DeepEqual(commentBySlug, want) {
+	if !cmp.Equal(commentBySlug, want) {
 		t.Errorf("Teams.EditCommentBySlug returned %+v, want %+v", commentBySlug, want)
 	}
+
+	methodName := "EditCommentByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.EditCommentByID(ctx, -1, -2, -3, -4, input)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.EditCommentByID(ctx, 1, 2, 3, 4, input)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
+
+	methodName = "EditCommentBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.EditCommentBySlug(ctx, "a\na", "b\nb", -3, -4, input)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.EditCommentBySlug(ctx, "a", "b", 3, 4, input)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService_DeleteComment(t *testing.T) {
@@ -275,7 +395,8 @@ func TestTeamsService_DeleteComment(t *testing.T) {
 	e := tdcEndpointByID("1", "2", "3", "4")
 	mux.HandleFunc(e, handlerFunc)
 
-	_, err := client.Teams.DeleteCommentByID(context.Background(), 1, 2, 3, 4)
+	ctx := context.Background()
+	_, err := client.Teams.DeleteCommentByID(ctx, 1, 2, 3, 4)
 	if err != nil {
 		t.Errorf("Teams.DeleteCommentByID returned error: %v", err)
 	}
@@ -283,8 +404,30 @@ func TestTeamsService_DeleteComment(t *testing.T) {
 	e = tdcEndpointBySlug("a", "b", "3", "4")
 	mux.HandleFunc(e, handlerFunc)
 
-	_, err = client.Teams.DeleteCommentBySlug(context.Background(), "a", "b", 3, 4)
+	_, err = client.Teams.DeleteCommentBySlug(ctx, "a", "b", 3, 4)
 	if err != nil {
 		t.Errorf("Teams.DeleteCommentBySlug returned error: %v", err)
 	}
+
+	methodName := "DeleteCommentByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Teams.DeleteCommentByID(ctx, -1, -2, -3, -4)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		resp, err := client.Teams.DeleteCommentByID(ctx, 1, 2, 3, 4)
+		return resp, err
+	})
+
+	methodName = "DeleteCommentBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Teams.DeleteCommentBySlug(ctx, "a\na", "b\nb", -3, -4)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		resp, err := client.Teams.DeleteCommentBySlug(ctx, "a", "b", 3, 4)
+		return resp, err
+	})
 }
