@@ -10,8 +10,9 @@ import (
 	"encoding/json"
 	"fmt"
 	"net/http"
-	"reflect"
 	"testing"
+
+	"github.com/google/go-cmp/cmp"
 )
 
 func TestTeamsService__ListTeamMembersByID(t *testing.T) {
@@ -25,15 +26,30 @@ func TestTeamsService__ListTeamMembersByID(t *testing.T) {
 	})
 
 	opt := &TeamListTeamMembersOptions{Role: "member", ListOptions: ListOptions{Page: 2}}
-	members, _, err := client.Teams.ListTeamMembersByID(context.Background(), 1, 2, opt)
+	ctx := context.Background()
+	members, _, err := client.Teams.ListTeamMembersByID(ctx, 1, 2, opt)
 	if err != nil {
 		t.Errorf("Teams.ListTeamMembersByID returned error: %v", err)
 	}
 
 	want := []*User{{ID: Int64(1)}}
-	if !reflect.DeepEqual(members, want) {
+	if !cmp.Equal(members, want) {
 		t.Errorf("Teams.ListTeamMembersByID returned %+v, want %+v", members, want)
 	}
+
+	const methodName = "ListTeamMembersByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListTeamMembersByID(ctx, -1, -2, opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListTeamMembersByID(ctx, 1, 2, opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListTeamMembersByID_notFound(t *testing.T) {
@@ -47,7 +63,8 @@ func TestTeamsService__ListTeamMembersByID_notFound(t *testing.T) {
 	})
 
 	opt := &TeamListTeamMembersOptions{Role: "member", ListOptions: ListOptions{Page: 2}}
-	members, resp, err := client.Teams.ListTeamMembersByID(context.Background(), 1, 2, opt)
+	ctx := context.Background()
+	members, resp, err := client.Teams.ListTeamMembersByID(ctx, 1, 2, opt)
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -57,6 +74,20 @@ func TestTeamsService__ListTeamMembersByID_notFound(t *testing.T) {
 	if members != nil {
 		t.Errorf("Teams.ListTeamMembersByID returned %+v, want nil", members)
 	}
+
+	const methodName = "ListTeamMembersByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListTeamMembersByID(ctx, 1, 2, opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListTeamMembersByID(ctx, 1, 2, opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListTeamMembersBySlug(t *testing.T) {
@@ -70,15 +101,30 @@ func TestTeamsService__ListTeamMembersBySlug(t *testing.T) {
 	})
 
 	opt := &TeamListTeamMembersOptions{Role: "member", ListOptions: ListOptions{Page: 2}}
-	members, _, err := client.Teams.ListTeamMembersBySlug(context.Background(), "o", "s", opt)
+	ctx := context.Background()
+	members, _, err := client.Teams.ListTeamMembersBySlug(ctx, "o", "s", opt)
 	if err != nil {
 		t.Errorf("Teams.ListTeamMembersBySlug returned error: %v", err)
 	}
 
 	want := []*User{{ID: Int64(1)}}
-	if !reflect.DeepEqual(members, want) {
+	if !cmp.Equal(members, want) {
 		t.Errorf("Teams.ListTeamMembersBySlug returned %+v, want %+v", members, want)
 	}
+
+	const methodName = "ListTeamMembersBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListTeamMembersBySlug(ctx, "\n", "\n", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListTeamMembersBySlug(ctx, "o", "s", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListTeamMembersBySlug_notFound(t *testing.T) {
@@ -92,7 +138,8 @@ func TestTeamsService__ListTeamMembersBySlug_notFound(t *testing.T) {
 	})
 
 	opt := &TeamListTeamMembersOptions{Role: "member", ListOptions: ListOptions{Page: 2}}
-	members, resp, err := client.Teams.ListTeamMembersBySlug(context.Background(), "o", "s", opt)
+	ctx := context.Background()
+	members, resp, err := client.Teams.ListTeamMembersBySlug(ctx, "o", "s", opt)
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -102,13 +149,28 @@ func TestTeamsService__ListTeamMembersBySlug_notFound(t *testing.T) {
 	if members != nil {
 		t.Errorf("Teams.ListTeamMembersBySlug returned %+v, want nil", members)
 	}
+
+	const methodName = "ListTeamMembersBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListTeamMembersBySlug(ctx, "o", "s", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListTeamMembersBySlug(ctx, "o", "s", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListTeamMembersBySlug_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Teams.ListTeamMembersBySlug(context.Background(), "%", "s", nil)
+	ctx := context.Background()
+	_, _, err := client.Teams.ListTeamMembersBySlug(ctx, "%", "s", nil)
 	testURLParseError(t, err)
 }
 
@@ -121,15 +183,30 @@ func TestTeamsService__GetTeamMembershipByID(t *testing.T) {
 		fmt.Fprint(w, `{"url":"u", "state":"active"}`)
 	})
 
-	membership, _, err := client.Teams.GetTeamMembershipByID(context.Background(), 1, 2, "u")
+	ctx := context.Background()
+	membership, _, err := client.Teams.GetTeamMembershipByID(ctx, 1, 2, "u")
 	if err != nil {
 		t.Errorf("Teams.GetTeamMembershipByID returned error: %v", err)
 	}
 
 	want := &Membership{URL: String("u"), State: String("active")}
-	if !reflect.DeepEqual(membership, want) {
+	if !cmp.Equal(membership, want) {
 		t.Errorf("Teams.GetTeamMembershipByID returned %+v, want %+v", membership, want)
 	}
+
+	const methodName = "GetTeamMembershipByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.GetTeamMembershipByID(ctx, -1, -2, "\n")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.GetTeamMembershipByID(ctx, 1, 2, "u")
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__GetTeamMembershipByID_notFound(t *testing.T) {
@@ -141,7 +218,8 @@ func TestTeamsService__GetTeamMembershipByID_notFound(t *testing.T) {
 		w.WriteHeader(http.StatusNotFound)
 	})
 
-	membership, resp, err := client.Teams.GetTeamMembershipByID(context.Background(), 1, 2, "u")
+	ctx := context.Background()
+	membership, resp, err := client.Teams.GetTeamMembershipByID(ctx, 1, 2, "u")
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -151,6 +229,20 @@ func TestTeamsService__GetTeamMembershipByID_notFound(t *testing.T) {
 	if membership != nil {
 		t.Errorf("Teams.GetTeamMembershipByID returned %+v, want nil", membership)
 	}
+
+	const methodName = "GetTeamMembershipByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.GetTeamMembershipByID(ctx, 1, 2, "u")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.GetTeamMembershipByID(ctx, 1, 2, "u")
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__GetTeamMembershipBySlug(t *testing.T) {
@@ -162,15 +254,30 @@ func TestTeamsService__GetTeamMembershipBySlug(t *testing.T) {
 		fmt.Fprint(w, `{"url":"u", "state":"active"}`)
 	})
 
-	membership, _, err := client.Teams.GetTeamMembershipBySlug(context.Background(), "o", "s", "u")
+	ctx := context.Background()
+	membership, _, err := client.Teams.GetTeamMembershipBySlug(ctx, "o", "s", "u")
 	if err != nil {
 		t.Errorf("Teams.GetTeamMembershipBySlug returned error: %v", err)
 	}
 
 	want := &Membership{URL: String("u"), State: String("active")}
-	if !reflect.DeepEqual(membership, want) {
+	if !cmp.Equal(membership, want) {
 		t.Errorf("Teams.GetTeamMembershipBySlug returned %+v, want %+v", membership, want)
 	}
+
+	const methodName = "GetTeamMembershipBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.GetTeamMembershipBySlug(ctx, "\n", "\n", "\n")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.GetTeamMembershipBySlug(ctx, "o", "s", "u")
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__GetTeamMembershipBySlug_notFound(t *testing.T) {
@@ -182,7 +289,8 @@ func TestTeamsService__GetTeamMembershipBySlug_notFound(t *testing.T) {
 		w.WriteHeader(http.StatusNotFound)
 	})
 
-	membership, resp, err := client.Teams.GetTeamMembershipBySlug(context.Background(), "o", "s", "u")
+	ctx := context.Background()
+	membership, resp, err := client.Teams.GetTeamMembershipBySlug(ctx, "o", "s", "u")
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -192,13 +300,28 @@ func TestTeamsService__GetTeamMembershipBySlug_notFound(t *testing.T) {
 	if membership != nil {
 		t.Errorf("Teams.GetTeamMembershipBySlug returned %+v, want nil", membership)
 	}
+
+	const methodName = "GetTeamMembershipBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.GetTeamMembershipBySlug(ctx, "o", "s", "u")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.GetTeamMembershipBySlug(ctx, "o", "s", "u")
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__GetTeamMembershipBySlug_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Teams.GetTeamMembershipBySlug(context.Background(), "%s", "s", "u")
+	ctx := context.Background()
+	_, _, err := client.Teams.GetTeamMembershipBySlug(ctx, "%s", "s", "u")
 	testURLParseError(t, err)
 }
 
@@ -213,22 +336,37 @@ func TestTeamsService__AddTeamMembershipByID(t *testing.T) {
 		json.NewDecoder(r.Body).Decode(v)
 
 		testMethod(t, r, "PUT")
-		if !reflect.DeepEqual(v, opt) {
+		if !cmp.Equal(v, opt) {
 			t.Errorf("Request body = %+v, want %+v", v, opt)
 		}
 
 		fmt.Fprint(w, `{"url":"u", "state":"pending"}`)
 	})
 
-	membership, _, err := client.Teams.AddTeamMembershipByID(context.Background(), 1, 2, "u", opt)
+	ctx := context.Background()
+	membership, _, err := client.Teams.AddTeamMembershipByID(ctx, 1, 2, "u", opt)
 	if err != nil {
 		t.Errorf("Teams.AddTeamMembershipByID returned error: %v", err)
 	}
 
 	want := &Membership{URL: String("u"), State: String("pending")}
-	if !reflect.DeepEqual(membership, want) {
+	if !cmp.Equal(membership, want) {
 		t.Errorf("Teams.AddTeamMembershipByID returned %+v, want %+v", membership, want)
 	}
+
+	const methodName = "AddTeamMembershipByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.AddTeamMembershipByID(ctx, -1, -2, "\n", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.AddTeamMembershipByID(ctx, 1, 2, "u", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__AddTeamMembershipByID_notFound(t *testing.T) {
@@ -242,14 +380,15 @@ func TestTeamsService__AddTeamMembershipByID_notFound(t *testing.T) {
 		json.NewDecoder(r.Body).Decode(v)
 
 		testMethod(t, r, "PUT")
-		if !reflect.DeepEqual(v, opt) {
+		if !cmp.Equal(v, opt) {
 			t.Errorf("Request body = %+v, want %+v", v, opt)
 		}
 
 		w.WriteHeader(http.StatusNotFound)
 	})
 
-	membership, resp, err := client.Teams.AddTeamMembershipByID(context.Background(), 1, 2, "u", opt)
+	ctx := context.Background()
+	membership, resp, err := client.Teams.AddTeamMembershipByID(ctx, 1, 2, "u", opt)
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -259,6 +398,20 @@ func TestTeamsService__AddTeamMembershipByID_notFound(t *testing.T) {
 	if membership != nil {
 		t.Errorf("Teams.AddTeamMembershipByID returned %+v, want nil", membership)
 	}
+
+	const methodName = "AddTeamMembershipByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.AddTeamMembershipByID(ctx, 1, 2, "u", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.AddTeamMembershipByID(ctx, 1, 2, "u", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__AddTeamMembershipBySlug(t *testing.T) {
@@ -272,22 +425,37 @@ func TestTeamsService__AddTeamMembershipBySlug(t *testing.T) {
 		json.NewDecoder(r.Body).Decode(v)
 
 		testMethod(t, r, "PUT")
-		if !reflect.DeepEqual(v, opt) {
+		if !cmp.Equal(v, opt) {
 			t.Errorf("Request body = %+v, want %+v", v, opt)
 		}
 
 		fmt.Fprint(w, `{"url":"u", "state":"pending"}`)
 	})
 
-	membership, _, err := client.Teams.AddTeamMembershipBySlug(context.Background(), "o", "s", "u", opt)
+	ctx := context.Background()
+	membership, _, err := client.Teams.AddTeamMembershipBySlug(ctx, "o", "s", "u", opt)
 	if err != nil {
 		t.Errorf("Teams.AddTeamMembershipBySlug returned error: %v", err)
 	}
 
 	want := &Membership{URL: String("u"), State: String("pending")}
-	if !reflect.DeepEqual(membership, want) {
+	if !cmp.Equal(membership, want) {
 		t.Errorf("Teams.AddTeamMembershipBySlug returned %+v, want %+v", membership, want)
 	}
+
+	const methodName = "AddTeamMembershipBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.AddTeamMembershipBySlug(ctx, "\n", "\n", "\n", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.AddTeamMembershipBySlug(ctx, "o", "s", "u", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__AddTeamMembershipBySlug_notFound(t *testing.T) {
@@ -301,14 +469,15 @@ func TestTeamsService__AddTeamMembershipBySlug_notFound(t *testing.T) {
 		json.NewDecoder(r.Body).Decode(v)
 
 		testMethod(t, r, "PUT")
-		if !reflect.DeepEqual(v, opt) {
+		if !cmp.Equal(v, opt) {
 			t.Errorf("Request body = %+v, want %+v", v, opt)
 		}
 
 		w.WriteHeader(http.StatusNotFound)
 	})
 
-	membership, resp, err := client.Teams.AddTeamMembershipBySlug(context.Background(), "o", "s", "u", opt)
+	ctx := context.Background()
+	membership, resp, err := client.Teams.AddTeamMembershipBySlug(ctx, "o", "s", "u", opt)
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -318,13 +487,28 @@ func TestTeamsService__AddTeamMembershipBySlug_notFound(t *testing.T) {
 	if membership != nil {
 		t.Errorf("Teams.AddTeamMembershipBySlug returned %+v, want nil", membership)
 	}
+
+	const methodName = "AddTeamMembershipBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.AddTeamMembershipBySlug(ctx, "o", "s", "u", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.AddTeamMembershipBySlug(ctx, "o", "s", "u", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__AddTeamMembershipBySlug_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Teams.AddTeamMembershipBySlug(context.Background(), "%", "s", "u", nil)
+	ctx := context.Background()
+	_, _, err := client.Teams.AddTeamMembershipBySlug(ctx, "%", "s", "u", nil)
 	testURLParseError(t, err)
 }
 
@@ -337,10 +521,21 @@ func TestTeamsService__RemoveTeamMembershipByID(t *testing.T) {
 		w.WriteHeader(http.StatusNoContent)
 	})
 
-	_, err := client.Teams.RemoveTeamMembershipByID(context.Background(), 1, 2, "u")
+	ctx := context.Background()
+	_, err := client.Teams.RemoveTeamMembershipByID(ctx, 1, 2, "u")
 	if err != nil {
 		t.Errorf("Teams.RemoveTeamMembershipByID returned error: %v", err)
 	}
+
+	const methodName = "RemoveTeamMembershipByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Teams.RemoveTeamMembershipByID(ctx, -1, -2, "\n")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		return client.Teams.RemoveTeamMembershipByID(ctx, 1, 2, "u")
+	})
 }
 
 func TestTeamsService__RemoveTeamMembershipByID_notFound(t *testing.T) {
@@ -352,13 +547,24 @@ func TestTeamsService__RemoveTeamMembershipByID_notFound(t *testing.T) {
 		w.WriteHeader(http.StatusNotFound)
 	})
 
-	resp, err := client.Teams.RemoveTeamMembershipByID(context.Background(), 1, 2, "u")
+	ctx := context.Background()
+	resp, err := client.Teams.RemoveTeamMembershipByID(ctx, 1, 2, "u")
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
 	if got, want := resp.Response.StatusCode, http.StatusNotFound; got != want {
 		t.Errorf("Teams.RemoveTeamMembershipByID returned status %d, want %d", got, want)
 	}
+
+	const methodName = "RemoveTeamMembershipByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Teams.RemoveTeamMembershipByID(ctx, 1, 2, "u")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		return client.Teams.RemoveTeamMembershipByID(ctx, 1, 2, "u")
+	})
 }
 
 func TestTeamsService__RemoveTeamMembershipBySlug(t *testing.T) {
@@ -370,10 +576,21 @@ func TestTeamsService__RemoveTeamMembershipBySlug(t *testing.T) {
 		w.WriteHeader(http.StatusNoContent)
 	})
 
-	_, err := client.Teams.RemoveTeamMembershipBySlug(context.Background(), "o", "s", "u")
+	ctx := context.Background()
+	_, err := client.Teams.RemoveTeamMembershipBySlug(ctx, "o", "s", "u")
 	if err != nil {
 		t.Errorf("Teams.RemoveTeamMembershipBySlug returned error: %v", err)
 	}
+
+	const methodName = "RemoveTeamMembershipBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Teams.RemoveTeamMembershipBySlug(ctx, "\n", "\n", "\n")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		return client.Teams.RemoveTeamMembershipBySlug(ctx, "o", "s", "u")
+	})
 }
 
 func TestTeamsService__RemoveTeamMembershipBySlug_notFound(t *testing.T) {
@@ -385,20 +602,32 @@ func TestTeamsService__RemoveTeamMembershipBySlug_notFound(t *testing.T) {
 		w.WriteHeader(http.StatusNotFound)
 	})
 
-	resp, err := client.Teams.RemoveTeamMembershipBySlug(context.Background(), "o", "s", "u")
+	ctx := context.Background()
+	resp, err := client.Teams.RemoveTeamMembershipBySlug(ctx, "o", "s", "u")
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
 	if got, want := resp.Response.StatusCode, http.StatusNotFound; got != want {
 		t.Errorf("Teams.RemoveTeamMembershipBySlug returned status %d, want %d", got, want)
 	}
+
+	const methodName = "RemoveTeamMembershipBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Teams.RemoveTeamMembershipBySlug(ctx, "o", "s", "u")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		return client.Teams.RemoveTeamMembershipBySlug(ctx, "o", "s", "u")
+	})
 }
 
 func TestTeamsService__RemoveTeamMembershipBySlug_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, err := client.Teams.RemoveTeamMembershipBySlug(context.Background(), "%", "s", "u")
+	ctx := context.Background()
+	_, err := client.Teams.RemoveTeamMembershipBySlug(ctx, "%", "s", "u")
 	testURLParseError(t, err)
 }
 
@@ -413,15 +642,30 @@ func TestTeamsService__ListPendingTeamInvitationsByID(t *testing.T) {
 	})
 
 	opt := &ListOptions{Page: 2}
-	invitations, _, err := client.Teams.ListPendingTeamInvitationsByID(context.Background(), 1, 2, opt)
+	ctx := context.Background()
+	invitations, _, err := client.Teams.ListPendingTeamInvitationsByID(ctx, 1, 2, opt)
 	if err != nil {
 		t.Errorf("Teams.ListPendingTeamInvitationsByID returned error: %v", err)
 	}
 
 	want := []*Invitation{{ID: Int64(1)}}
-	if !reflect.DeepEqual(invitations, want) {
+	if !cmp.Equal(invitations, want) {
 		t.Errorf("Teams.ListPendingTeamInvitationsByID returned %+v, want %+v", invitations, want)
 	}
+
+	const methodName = "ListPendingTeamInvitationsByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListPendingTeamInvitationsByID(ctx, -1, -2, opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListPendingTeamInvitationsByID(ctx, 1, 2, opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListPendingTeamInvitationsByID_notFound(t *testing.T) {
@@ -435,7 +679,8 @@ func TestTeamsService__ListPendingTeamInvitationsByID_notFound(t *testing.T) {
 	})
 
 	opt := &ListOptions{Page: 2}
-	invitations, resp, err := client.Teams.ListPendingTeamInvitationsByID(context.Background(), 1, 2, opt)
+	ctx := context.Background()
+	invitations, resp, err := client.Teams.ListPendingTeamInvitationsByID(ctx, 1, 2, opt)
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -445,6 +690,20 @@ func TestTeamsService__ListPendingTeamInvitationsByID_notFound(t *testing.T) {
 	if invitations != nil {
 		t.Errorf("Teams.RemoveTeamMembershipByID returned %+v, want nil", invitations)
 	}
+
+	const methodName = "ListPendingTeamInvitationsByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListPendingTeamInvitationsByID(ctx, 1, 2, opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListPendingTeamInvitationsByID(ctx, 1, 2, opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListPendingTeamInvitationsBySlug(t *testing.T) {
@@ -458,15 +717,30 @@ func TestTeamsService__ListPendingTeamInvitationsBySlug(t *testing.T) {
 	})
 
 	opt := &ListOptions{Page: 2}
-	invitations, _, err := client.Teams.ListPendingTeamInvitationsBySlug(context.Background(), "o", "s", opt)
+	ctx := context.Background()
+	invitations, _, err := client.Teams.ListPendingTeamInvitationsBySlug(ctx, "o", "s", opt)
 	if err != nil {
 		t.Errorf("Teams.ListPendingTeamInvitationsByID returned error: %v", err)
 	}
 
 	want := []*Invitation{{ID: Int64(1)}}
-	if !reflect.DeepEqual(invitations, want) {
+	if !cmp.Equal(invitations, want) {
 		t.Errorf("Teams.ListPendingTeamInvitationsByID returned %+v, want %+v", invitations, want)
 	}
+
+	const methodName = "ListPendingTeamInvitationsBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListPendingTeamInvitationsBySlug(ctx, "\n", "\n", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListPendingTeamInvitationsBySlug(ctx, "o", "s", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListPendingTeamInvitationsBySlug_notFound(t *testing.T) {
@@ -480,7 +754,8 @@ func TestTeamsService__ListPendingTeamInvitationsBySlug_notFound(t *testing.T) {
 	})
 
 	opt := &ListOptions{Page: 2}
-	invitations, resp, err := client.Teams.ListPendingTeamInvitationsBySlug(context.Background(), "o", "s", opt)
+	ctx := context.Background()
+	invitations, resp, err := client.Teams.ListPendingTeamInvitationsBySlug(ctx, "o", "s", opt)
 	if err == nil {
 		t.Errorf("Expected HTTP 404 response")
 	}
@@ -490,12 +765,27 @@ func TestTeamsService__ListPendingTeamInvitationsBySlug_notFound(t *testing.T) {
 	if invitations != nil {
 		t.Errorf("Teams.RemoveTeamMembershipByID returned %+v, want nil", invitations)
 	}
+
+	const methodName = "ListPendingTeamInvitationsBySlug"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Teams.ListPendingTeamInvitationsBySlug(ctx, "o", "s", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Teams.ListPendingTeamInvitationsBySlug(ctx, "o", "s", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestTeamsService__ListPendingTeamInvitationsBySlug_invalidOrg(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Teams.ListPendingTeamInvitationsBySlug(context.Background(), "%", "s", nil)
+	ctx := context.Background()
+	_, _, err := client.Teams.ListPendingTeamInvitationsBySlug(ctx, "%", "s", nil)
 	testURLParseError(t, err)
 }
