@@ -10,11 +10,12 @@ import (
 	"encoding/json"
 	"fmt"
 	"net/http"
-	"reflect"
 	"testing"
+
+	"github.com/google/go-cmp/cmp"
 )
 
-func TestUser_marshall(t *testing.T) {
+func TestUser_Marshal(t *testing.T) {
 	testJSONMarshal(t, &User{}, "{}")
 
 	u := &User{
@@ -69,15 +70,30 @@ func TestUsersService_Get_authenticatedUser(t *testing.T) {
 		fmt.Fprint(w, `{"id":1}`)
 	})
 
-	user, _, err := client.Users.Get(context.Background(), "")
+	ctx := context.Background()
+	user, _, err := client.Users.Get(ctx, "")
 	if err != nil {
 		t.Errorf("Users.Get returned error: %v", err)
 	}
 
 	want := &User{ID: Int64(1)}
-	if !reflect.DeepEqual(user, want) {
+	if !cmp.Equal(user, want) {
 		t.Errorf("Users.Get returned %+v, want %+v", user, want)
 	}
+
+	const methodName = "Get"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Users.Get(ctx, "\n")
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Users.Get(ctx, "")
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestUsersService_Get_specifiedUser(t *testing.T) {
@@ -89,13 +105,14 @@ func TestUsersService_Get_specifiedUser(t *testing.T) {
 		fmt.Fprint(w, `{"id":1}`)
 	})
 
-	user, _, err := client.Users.Get(context.Background(), "u")
+	ctx := context.Background()
+	user, _, err := client.Users.Get(ctx, "u")
 	if err != nil {
 		t.Errorf("Users.Get returned error: %v", err)
 	}
 
 	want := &User{ID: Int64(1)}
-	if !reflect.DeepEqual(user, want) {
+	if !cmp.Equal(user, want) {
 		t.Errorf("Users.Get returned %+v, want %+v", user, want)
 	}
 }
@@ -104,7 +121,8 @@ func TestUsersService_Get_invalidUser(t *testing.T) {
 	client, _, _, teardown := setup()
 	defer teardown()
 
-	_, _, err := client.Users.Get(context.Background(), "%")
+	ctx := context.Background()
+	_, _, err := client.Users.Get(ctx, "%")
 	testURLParseError(t, err)
 }
 
@@ -117,15 +135,30 @@ func TestUsersService_GetByID(t *testing.T) {
 		fmt.Fprint(w, `{"id":1}`)
 	})
 
-	user, _, err := client.Users.GetByID(context.Background(), 1)
+	ctx := context.Background()
+	user, _, err := client.Users.GetByID(ctx, 1)
 	if err != nil {
 		t.Fatalf("Users.GetByID returned error: %v", err)
 	}
 
 	want := &User{ID: Int64(1)}
-	if !reflect.DeepEqual(user, want) {
+	if !cmp.Equal(user, want) {
 		t.Errorf("Users.GetByID returned %+v, want %+v", user, want)
 	}
+
+	const methodName = "GetByID"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Users.GetByID(ctx, -1)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Users.GetByID(ctx, 1)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestUsersService_Edit(t *testing.T) {
@@ -139,22 +172,32 @@ func TestUsersService_Edit(t *testing.T) {
 		json.NewDecoder(r.Body).Decode(v)
 
 		testMethod(t, r, "PATCH")
-		if !reflect.DeepEqual(v, input) {
+		if !cmp.Equal(v, input) {
 			t.Errorf("Request body = %+v, want %+v", v, input)
 		}
 
 		fmt.Fprint(w, `{"id":1}`)
 	})
 
-	user, _, err := client.Users.Edit(context.Background(), input)
+	ctx := context.Background()
+	user, _, err := client.Users.Edit(ctx, input)
 	if err != nil {
 		t.Errorf("Users.Edit returned error: %v", err)
 	}
 
 	want := &User{ID: Int64(1)}
-	if !reflect.DeepEqual(user, want) {
+	if !cmp.Equal(user, want) {
 		t.Errorf("Users.Edit returned %+v, want %+v", user, want)
 	}
+
+	const methodName = "Edit"
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Users.Edit(ctx, input)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestUsersService_GetHovercard(t *testing.T) {
@@ -168,15 +211,30 @@ func TestUsersService_GetHovercard(t *testing.T) {
 	})
 
 	opt := &HovercardOptions{SubjectType: "repository", SubjectID: "20180408"}
-	hovercard, _, err := client.Users.GetHovercard(context.Background(), "u", opt)
+	ctx := context.Background()
+	hovercard, _, err := client.Users.GetHovercard(ctx, "u", opt)
 	if err != nil {
 		t.Errorf("Users.GetHovercard returned error: %v", err)
 	}
 
 	want := &Hovercard{Contexts: []*UserContext{{Message: String("Owns this repository"), Octicon: String("repo")}}}
-	if !reflect.DeepEqual(hovercard, want) {
+	if !cmp.Equal(hovercard, want) {
 		t.Errorf("Users.GetHovercard returned %+v, want %+v", hovercard, want)
 	}
+
+	const methodName = "GetHovercard"
+	testBadOptions(t, methodName, func() (err error) {
+		_, _, err = client.Users.GetHovercard(ctx, "\n", opt)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Users.GetHovercard(ctx, "u", opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestUsersService_ListAll(t *testing.T) {
@@ -190,15 +248,25 @@ func TestUsersService_ListAll(t *testing.T) {
 	})
 
 	opt := &UserListOptions{1, ListOptions{Page: 2}}
-	users, _, err := client.Users.ListAll(context.Background(), opt)
+	ctx := context.Background()
+	users, _, err := client.Users.ListAll(ctx, opt)
 	if err != nil {
 		t.Errorf("Users.Get returned error: %v", err)
 	}
 
 	want := []*User{{ID: Int64(2)}}
-	if !reflect.DeepEqual(users, want) {
+	if !cmp.Equal(users, want) {
 		t.Errorf("Users.ListAll returned %+v, want %+v", users, want)
 	}
+
+	const methodName = "ListAll"
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Users.ListAll(ctx, opt)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestUsersService_ListInvitations(t *testing.T) {
@@ -210,15 +278,25 @@ func TestUsersService_ListInvitations(t *testing.T) {
 		fmt.Fprintf(w, `[{"id":1}, {"id":2}]`)
 	})
 
-	got, _, err := client.Users.ListInvitations(context.Background(), nil)
+	ctx := context.Background()
+	got, _, err := client.Users.ListInvitations(ctx, nil)
 	if err != nil {
 		t.Errorf("Users.ListInvitations returned error: %v", err)
 	}
 
 	want := []*RepositoryInvitation{{ID: Int64(1)}, {ID: Int64(2)}}
-	if !reflect.DeepEqual(got, want) {
+	if !cmp.Equal(got, want) {
 		t.Errorf("Users.ListInvitations = %+v, want %+v", got, want)
 	}
+
+	const methodName = "ListInvitations"
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		got, resp, err := client.Users.ListInvitations(ctx, nil)
+		if got != nil {
+			t.Errorf("testNewRequestAndDoFailure %v = %#v, want nil", methodName, got)
+		}
+		return resp, err
+	})
 }
 
 func TestUsersService_ListInvitations_withOptions(t *testing.T) {
@@ -233,11 +311,13 @@ func TestUsersService_ListInvitations_withOptions(t *testing.T) {
 		fmt.Fprintf(w, `[{"id":1}, {"id":2}]`)
 	})
 
-	_, _, err := client.Users.ListInvitations(context.Background(), &ListOptions{Page: 2})
+	ctx := context.Background()
+	_, _, err := client.Users.ListInvitations(ctx, &ListOptions{Page: 2})
 	if err != nil {
 		t.Errorf("Users.ListInvitations returned error: %v", err)
 	}
 }
+
 func TestUsersService_AcceptInvitation(t *testing.T) {
 	client, mux, _, teardown := setup()
 	defer teardown()
@@ -247,9 +327,20 @@ func TestUsersService_AcceptInvitation(t *testing.T) {
 		w.WriteHeader(http.StatusNoContent)
 	})
 
-	if _, err := client.Users.AcceptInvitation(context.Background(), 1); err != nil {
+	ctx := context.Background()
+	if _, err := client.Users.AcceptInvitation(ctx, 1); err != nil {
 		t.Errorf("Users.AcceptInvitation returned error: %v", err)
 	}
+
+	const methodName = "AcceptInvitation"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Users.AcceptInvitation(ctx, -1)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		return client.Users.AcceptInvitation(ctx, 1)
+	})
 }
 
 func TestUsersService_DeclineInvitation(t *testing.T) {
@@ -261,7 +352,18 @@ func TestUsersService_DeclineInvitation(t *testing.T) {
 		w.WriteHeader(http.StatusNoContent)
 	})
 
-	if _, err := client.Users.DeclineInvitation(context.Background(), 1); err != nil {
+	ctx := context.Background()
+	if _, err := client.Users.DeclineInvitation(ctx, 1); err != nil {
 		t.Errorf("Users.DeclineInvitation returned error: %v", err)
 	}
+
+	const methodName = "DeclineInvitation"
+	testBadOptions(t, methodName, func() (err error) {
+		_, err = client.Users.DeclineInvitation(ctx, -1)
+		return err
+	})
+
+	testNewRequestAndDoFailure(t, methodName, client, func() (*Response, error) {
+		return client.Users.DeclineInvitation(ctx, 1)
+	})
 }
