@@ -6,13 +6,17 @@
 // update-urls updates GitHub URL docs for each service endpoint.
 //
 // It is meant to be used periodically by go-github repo maintainers
-// to update stale GitHub Developer v3 API documenation URLs.
+// to update stale GitHub Developer v3 API documentation URLs.
 //
 // Usage (from go-github directory):
 //   go run ./update-urls/main.go
 //   go generate ./...
 //   go test ./...
 //   go vet ./...
+//
+// When confronted with "PLEASE CHECK MANUALLY AND FIX", the problematic
+// URL needs to be debugged. To debug a specific file, run like this:
+//   go run ./update-urls/main.go -v -d enterprise_actions_runners.go
 package main
 
 import (
@@ -32,10 +36,13 @@ import (
 )
 
 const (
-	skipPrefix = "gen-"
+	codeLegacySplitString = `<code>`
+	codeSplitString       = `<code class="hljs language-javascript"><span class="hljs-keyword">await</span> octokit.request(<span class="hljs-string">&apos;`
+	fragmentIDString      = `<h3 id="`
+	skipPrefix            = "gen-"
 
-	enterpriseURL = "developer.github.com/enterprise"
-	stdURL        = "developer.github.com"
+	// enterpriseURL = "docs.github.com"
+	stdURL = "docs.github.com"
 
 	enterpriseRefFmt = "// GitHub Enterprise API docs: %v"
 	stdRefFmt        = "// GitHub API docs: %v"
@@ -48,34 +55,39 @@ var (
 	// skipMethods holds methods which are skipped because they do not have GitHub v3
 	// API URLs or are otherwise problematic in parsing, discovering, and/or fixing.
 	skipMethods = map[string]bool{
-		"ActionsService.DownloadArtifact":            true,
-		"AdminService.CreateOrg":                     true,
-		"AdminService.CreateUser":                    true,
-		"AdminService.CreateUserImpersonation":       true,
-		"AdminService.DeleteUserImpersonation":       true,
-		"AdminService.GetAdminStats":                 true,
-		"AdminService.RenameOrg":                     true,
-		"AdminService.RenameOrgByName":               true,
-		"AdminService.UpdateTeamLDAPMapping":         true,
-		"AdminService.UpdateUserLDAPMapping":         true,
-		"AppsService.FindRepositoryInstallationByID": true,
-		"AuthorizationsService.CreateImpersonation":  true,
-		"AuthorizationsService.DeleteImpersonation":  true,
-		"MarketplaceService.marketplaceURI":          true,
-		"OrganizationsService.GetByID":               true,
-		"RepositoriesService.DeletePreReceiveHook":   true,
-		"RepositoriesService.DownloadContents":       true,
-		"RepositoriesService.GetArchiveLink":         true,
-		"RepositoriesService.GetByID":                true,
-		"RepositoriesService.GetPreReceiveHook":      true,
-		"RepositoriesService.ListPreReceiveHooks":    true,
-		"RepositoriesService.UpdatePreReceiveHook":   true,
-		"SearchService.search":                       true,
-		"UsersService.DemoteSiteAdmin":               true,
-		"UsersService.GetByID":                       true,
-		"UsersService.PromoteSiteAdmin":              true,
-		"UsersService.Suspend":                       true,
-		"UsersService.Unsuspend":                     true,
+		"ActionsService.DownloadArtifact":              true,
+		"AdminService.CreateOrg":                       true,
+		"AdminService.CreateUser":                      true,
+		"AdminService.CreateUserImpersonation":         true,
+		"AdminService.DeleteUserImpersonation":         true,
+		"AdminService.GetAdminStats":                   true,
+		"AdminService.RenameOrg":                       true,
+		"AdminService.RenameOrgByName":                 true,
+		"AdminService.UpdateTeamLDAPMapping":           true,
+		"AdminService.UpdateUserLDAPMapping":           true,
+		"AppsService.FindRepositoryInstallationByID":   true,
+		"AuthorizationsService.CreateImpersonation":    true,
+		"AuthorizationsService.DeleteImpersonation":    true,
+		"IssueImportService.CheckStatus":               true,
+		"IssueImportService.CheckStatusSince":          true,
+		"IssueImportService.Create":                    true,
+		"MarketplaceService.marketplaceURI":            true,
+		"OrganizationsService.GetByID":                 true,
+		"RepositoriesService.DeletePreReceiveHook":     true,
+		"RepositoriesService.DownloadContents":         true,
+		"RepositoriesService.DownloadContentsWithMeta": true,
+		"RepositoriesService.GetArchiveLink":           true,
+		"RepositoriesService.GetByID":                  true,
+		"RepositoriesService.GetPreReceiveHook":        true,
+		"RepositoriesService.ListPreReceiveHooks":      true,
+		"RepositoriesService.UpdatePreReceiveHook":     true,
+		"SearchService.search":                         true,
+		"TeamsService.ListTeamMembersByID":             true,
+		"UsersService.DemoteSiteAdmin":                 true,
+		"UsersService.GetByID":                         true,
+		"UsersService.PromoteSiteAdmin":                true,
+		"UsersService.Suspend":                         true,
+		"UsersService.Unsuspend":                       true,
 	}
 
 	helperOverrides = map[string]overrideFunc{
@@ -90,7 +102,8 @@ var (
 		"OrganizationsService.EditOrgMembership: PUT user/memberships/orgs/%v":  "PATCH",
 	}
 
-	paramRE = regexp.MustCompile(`:[a-z_]+`)
+	paramLegacyRE = regexp.MustCompile(`:[a-z_]+`)
+	paramRE       = regexp.MustCompile(`{[a-z_]+}`)
 )
 
 type overrideFunc func(arg string) (httpMethod, url string)
@@ -202,7 +215,10 @@ func validateRewriteURLs(usedHelpers usedHelpersMap, endpointsByFilename endpoin
 				// Make sure URL is up-to-date.
 				switch {
 				case len(endpoint.enterpriseRefLines) > 1:
-					log.Printf("WARNING: multiple Enterprise GitHub URLs found - skipping: %#v", endpoint.enterpriseRefLines)
+					log.Printf("WARNING: multiple Enterprise GitHub URLs found - skipping:")
+					for i, refLine := range endpoint.enterpriseRefLines {
+						log.Printf("line %v: %#v", i, refLine)
+					}
 				case len(endpoint.enterpriseRefLines) > 0:
 					line := fmt.Sprintf(enterpriseRefFmt, url)
 					cmt := endpoint.enterpriseRefLines[0]
@@ -487,10 +503,10 @@ func resolveHelpersAndCacheDocs(endpoints endpointsMap, docCache documentCacheWr
 		endpointsByFilename[v.filename] = append(endpointsByFilename[v.filename], v)
 
 		for _, cmt := range v.enterpriseRefLines {
-			docCache.CacheDocFromInternet(cmt.Text)
+			docCache.CacheDocFromInternet(cmt.Text, v.filename)
 		}
 		for _, cmt := range v.stdRefLines {
-			docCache.CacheDocFromInternet(cmt.Text)
+			docCache.CacheDocFromInternet(cmt.Text, v.filename)
 		}
 
 		if v.httpMethod == "" && v.helperMethod != "" {
@@ -515,7 +531,7 @@ type documentCacheReader interface {
 }
 
 type documentCacheWriter interface {
-	CacheDocFromInternet(urlWithFragmentID string)
+	CacheDocFromInternet(urlWithFragmentID, filename string)
 }
 
 // documentCache implements documentCacheReader and documentCachWriter.
@@ -529,7 +545,7 @@ func (dc *documentCache) UrlByMethodAndPath(methodAndPath string) (string, bool)
 	return url, ok
 }
 
-func (dc *documentCache) CacheDocFromInternet(urlWithID string) {
+func (dc *documentCache) CacheDocFromInternet(urlWithID, filename string) {
 	if dc.apiDocs == nil {
 		dc.apiDocs = map[string]map[string][]*Endpoint{} // cached by URL, then mapped by web fragment identifier.
 		dc.urlByMethodAndPath = map[string]string{}
@@ -540,29 +556,31 @@ func (dc *documentCache) CacheDocFromInternet(urlWithID string) {
 		return // already cached
 	}
 
-	// TODO: Enterprise URLs are currently causing problems - for example:
-	// GET https://developer.github.com/enterprise/v3/enterprise-admin/users/
-	// returns StatusCode=404
-	if strings.Contains(url, "enterprise") {
-		logf("Skipping troublesome Enterprise URL: %v", url)
-		return
-	}
-
 	logf("GET %q ...", url)
 	resp, err := http.Get(url)
 	check("Unable to get URL: %v: %v", url, err)
 	if resp.StatusCode != http.StatusOK {
-		log.Fatalf("url %v - StatusCode=%v", url, resp.StatusCode)
+		log.Fatalf("filename: %v - url %v - StatusCode=%v", filename, url, resp.StatusCode)
 	}
 
+	finalURL := resp.Request.URL.String()
+	url = getURL(finalURL)
+	logf("The final URL is: %v; url=%v\n", finalURL, url)
+
 	b, err := ioutil.ReadAll(resp.Body)
 	check("Unable to read body of URL: %v, %v", url, err)
 	check("Unable to close body of URL: %v, %v", url, resp.Body.Close())
 	dc.apiDocs[url] = parseWebPageEndpoints(string(b))
+	logf("Found %v web page fragment identifiers.", len(dc.apiDocs[url]))
+	if len(dc.apiDocs[url]) == 0 {
+		logf("webage text: %s", b)
+	}
 
 	// Now reverse-map the methods+paths to URLs.
 	for fragID, v := range dc.apiDocs[url] {
+		logf("For fragID=%q, found %v endpoints.", fragID, len(v))
 		for _, endpoint := range v {
+			logf("For fragID=%q, endpoint=%q, found %v paths.", fragID, endpoint, len(endpoint.urlFormats))
 			for _, path := range endpoint.urlFormats {
 				methodAndPath := fmt.Sprintf("%v %v", endpoint.httpMethod, path)
 				dc.urlByMethodAndPath[methodAndPath] = fmt.Sprintf("%v#%v", url, fragID)
@@ -637,12 +655,12 @@ func (e *Endpoint) String() string {
 	return b.String()
 }
 
-func (ep *Endpoint) checkHttpMethodOverride(path string) {
-	lookupOverride := fmt.Sprintf("%v.%v: %v %v", ep.serviceName, ep.endpointName, ep.httpMethod, path)
+func (e *Endpoint) checkHttpMethodOverride(path string) {
+	lookupOverride := fmt.Sprintf("%v.%v: %v %v", e.serviceName, e.endpointName, e.httpMethod, path)
 	logf("Looking up override for %q", lookupOverride)
 	if v, ok := methodOverrides[lookupOverride]; ok {
 		logf("overriding method for %v to %q", lookupOverride, v)
-		ep.httpMethod = v
+		e.httpMethod = v
 		return
 	}
 }
@@ -701,9 +719,10 @@ func processAST(filename string, f *ast.File, services servicesMap, endpoints en
 				endpointComments = decl.Doc.List
 				for i, comment := range decl.Doc.List {
 					logf("doc.comment[%v] = %#v", i, *comment)
-					if strings.Contains(comment.Text, enterpriseURL) {
-						enterpriseRefLines = append(enterpriseRefLines, comment)
-					} else if strings.Contains(comment.Text, stdURL) {
+					// if strings.Contains(comment.Text, enterpriseURL) {
+					// 	enterpriseRefLines = append(enterpriseRefLines, comment)
+					// } else
+					if strings.Contains(comment.Text, stdURL) {
 						stdRefLines = append(stdRefLines, comment)
 					}
 				}
@@ -943,6 +962,10 @@ func processAssignStmt(receiverName string, stmt *ast.AssignStmt) (httpMethod, u
 			logf("processAssignStmt: *ast.SelectorExpr: %#v", *expr)
 		case *ast.UnaryExpr: // OpPos, Op, X
 			logf("processAssignStmt: *ast.UnaryExpr: %#v", *expr)
+		case *ast.TypeAssertExpr: // X, Lparen, Type, Rparen
+			logf("processAssignStmt: *ast.TypeAssertExpr: %#v", *expr)
+		case *ast.Ident: // NamePos, Name, Obj
+			logf("processAssignStmt: *ast.Ident: %#v", *expr)
 		default:
 			log.Fatalf("unhandled AssignStmt Rhs type: %T", expr)
 		}
@@ -1105,41 +1128,21 @@ func parseWebPageEndpoints(buf string) map[string][]*Endpoint {
 	//   ...
 	//   </optgroup>
 
-	parts := strings.Split(buf, "<code>")
+	parts := splitHTML(buf)
 	var lastFragmentID string
 	for _, part := range parts {
 		for _, method := range httpMethods {
 			if strings.HasPrefix(part, method) {
-				eol := strings.Index(part, "\n")
-				if eol < 0 {
-					eol = len(part)
+				endpoint := parseEndpoint(part, method)
+				if lastFragmentID == "" {
+					log.Fatalf("parseWebPageEndpoints: empty lastFragmentID")
 				}
-				if v := strings.Index(part, "<"); v > len(method) && v < eol {
-					eol = v
-				}
-				if v := strings.Index(part, "{"); v > len(method) && v < eol {
-					eol = v
-				}
-				path := strings.TrimSpace(part[len(method):eol])
-				if strings.HasPrefix(path, ":server") { // Hack to remove :server
-					path = strings.TrimPrefix(path, ":server")
-				}
-				path = paramRE.ReplaceAllString(path, "%v")
-				// strip leading garbage
-				if i := strings.Index(path, "/"); i >= 0 {
-					path = path[i+1:]
-				}
-				path = strings.TrimSuffix(path, ".")
-				logf("Found %v %v", method, path)
-				result[lastFragmentID] = append(result[lastFragmentID], &Endpoint{
-					urlFormats: []string{path},
-					httpMethod: method,
-				})
+				result[lastFragmentID] = append(result[lastFragmentID], endpoint)
 			}
 		}
 
-		if i := strings.LastIndex(part, "<a id="); i >= 0 {
-			b := part[i+7:]
+		if i := strings.LastIndex(part, fragmentIDString); i >= 0 {
+			b := part[i+len(fragmentIDString):]
 			i = strings.Index(b, `"`)
 			if i >= 0 {
 				lastFragmentID = b[:i]
@@ -1151,6 +1154,60 @@ func parseWebPageEndpoints(buf string) map[string][]*Endpoint {
 	return result
 }
 
+func splitHTML(buf string) []string {
+	var result []string
+	for buf != "" {
+		i := strings.Index(buf, codeLegacySplitString)
+		j := strings.Index(buf, codeSplitString)
+		switch {
+		case i < 0 && j < 0:
+			result = append(result, buf)
+			buf = ""
+		case j < 0, i >= 0 && j >= 0 && i < j:
+			result = append(result, buf[:i])
+			buf = buf[i+len(codeLegacySplitString):]
+		case i < 0, i >= 0 && j >= 0 && j < i:
+			result = append(result, buf[:j])
+			buf = buf[j+len(codeSplitString):]
+		default:
+			log.Fatalf("splitHTML: i=%v, j=%v", i, j)
+		}
+	}
+	return result
+}
+
+func parseEndpoint(s, method string) *Endpoint {
+	eol := strings.Index(s, "\n")
+	if eol < 0 {
+		eol = len(s)
+	}
+	if v := strings.Index(s, "&apos;"); v > len(method) && v < eol {
+		eol = v
+	}
+	if v := strings.Index(s, "<"); v > len(method) && v < eol {
+		eol = v
+	}
+	// if v := strings.Index(s, "{"); v > len(method) && v < eol {
+	// 	eol = v
+	// }
+	path := strings.TrimSpace(s[len(method):eol])
+	if strings.HasPrefix(path, "{server}") { // Hack to remove {server}
+		path = strings.TrimPrefix(path, "{server}")
+	}
+	path = paramLegacyRE.ReplaceAllString(path, "%v")
+	path = paramRE.ReplaceAllString(path, "%v")
+	// strip leading garbage
+	if i := strings.Index(path, "/"); i >= 0 {
+		path = path[i+1:]
+	}
+	path = strings.TrimSuffix(path, ".")
+	logf("Found endpoint: %v %v", method, path)
+	return &Endpoint{
+		urlFormats: []string{path},
+		httpMethod: method,
+	}
+}
+
 var httpMethods = []string{
 	"GET",
 	"HEAD",
